#!/usr/bin/env python
# Coolan Confidential
# Copyright (c) Coolan, Inc 2014 All Rights Reserved
#
# NOTICE:  All information contained herein is, and remains
# the property of Coolan, Inc.  The intellectual and
# technical concepts contained #herein are proprietary to
# Coolan, Inc and may be covered by U.S. and Foreign Patents,
# patents in process, and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material
# is strictly forbidden unless prior written permission is obtained
# from Coolan, Inc.
# This code and information are provided "as is" without warranty of any
# kind, either expressed or implied, including but not limited to the
# implied warranties of mechantability and/or fitness for a
# particular purpose.
import getopt

from common import *
from mcelogConfigurationSetup import mcelog_setup


def configure(customer_id, username, password, proxy_url, run_coolan_runner, verify, no_proxy=False):
    print "%s : Start writing Coolan configuration." % get_timestamp()
    config_file_path = get_config_file()
    # save original file ownership details
    stat = os.stat(config_file_path)
    uid, gid = stat[4], stat[5]
    for line in fileinput.input(config_file_path, inplace=True):
        if customer_id:
            line = re.sub(r'^customerID.+', "customerID=" + customer_id, line.rstrip())
            config.set(s.AUTH_SECTION, 'customerID', customer_id)
        if username:
            line = re.sub(r'^username.+', "username=" + username, line.rstrip())
            config.set(s.AUTH_SECTION, 'username', username)
        if password:
            line = re.sub(r'^password.+', "password=" + password, line.rstrip())
            config.set(s.AUTH_SECTION, 'password', password)
        if proxy_url:
            line = re.sub(r'^#?proxyUrl.+', "proxyUrl=" + proxy_url, line.rstrip())
            config.set(s.AUTH_SECTION, 'proxyUrl', proxy_url)
        elif not proxy_url.strip or no_proxy:
            line = re.sub(r'^#?proxyUrl.+', "#proxyUrl=https://<proxy host>:<proxy port>/", line.rstrip())
            config.remove_option(s.AUTH_SECTION, 'proxyUrl')
        if run_coolan_runner:
            if is_input_string_true(run_coolan_runner):
                line = re.sub(r'^run_coolan_runner.+', "run_coolan_runner=Yes", line.rstrip())
                config.set(s.SETTINGS, 'run_coolan_runner', "Yes")
            else:
                line = re.sub(r'^run_coolan_runner.+', "run_coolan_runner=No", line.rstrip())
                config.set(s.SETTINGS, 'run_coolan_runner', "No")
        if verify:
            if is_input_string_true(verify):
                line = re.sub(r'^verify.+', "verify=Yes", line.rstrip())
                config.set(s.SETTINGS, 'verify', "Yes")
            else:
                line = re.sub(r'^verify.+', "verify=No", line.rstrip())
                config.set(s.SETTINGS, 'verify', "No")
        print line.rstrip()
    fileinput.close()
    # restore original file ownership
    os.chown(config_file_path, uid, gid)

    if run_coolan_runner:
        if is_input_string_true(run_coolan_runner):
            print "%s : Coolan runner has been turned ON." % get_timestamp()
        else:
            print "%s : Coolan runner has been turned OFF." % get_timestamp()

    print "%s : Done writing Coolan configuration. The Coolan config file is located at: %s" % (get_timestamp(), config_file_path)
    # import here so it will read from the new config
    if is_config_on('verify') and is_config_on('run_coolan_runner'):
        from verifyConfig import verify

        verify()


def main():
    try:
        # Note: options is the string of option letters that the script wants to recognize, with
        # options that require an argument followed by a colon (':') i.e. -i fileNam
        opts, args = getopt.getopt(sys.argv[1:], "c:u:p:x:",
                                   ["customerID=", "username=", "password=", "proxyUrl=", "noProxy", "runCoolanRunner=", "verify=", "defaultMcelogSetup"])
    except getopt.GetoptError as err:
        # print help information and exit:
        print(err)  # will print something like "option -a not recognized"
        sys.exit(2)

    customer_id = ""
    username = ""
    password = ""
    proxy_url = ""
    no_proxy = False
    run_coolan_runner = ""
    verify = ""

    for o, a in opts:
        if o in ("-c", "--customerID"):
            customer_id = a
        elif o in ("-u", "--username"):
            username = a
        elif o in ("-p", "--password"):
            password = a
        elif o in ("-x", "--proxyUrl"):
            proxy_url = a
        elif o == "--noProxy":
            no_proxy = True
        elif o == "--runCoolanRunner":
            run_coolan_runner = a
        elif o == "--verify":
            verify = a
        elif o == "--defaultMcelogSetup":
            mcelog_setup()
        else:
            assert False, "unhandled option"
    configure(customer_id.strip(), username.strip(), password.strip(), proxy_url.strip(), run_coolan_runner.strip(), verify.strip(),  no_proxy)


if __name__ == "__main__":
    main()
